get_flow: Extract nodes and edges from R code

Description Usage Arguments Value

View source: R/ui.R

Description

Extract nodes and edges from R code

Usage

1
get_flow(path_to_file, ignore_source = NULL)

Arguments

path_to_file

character: A file path string

ignore_source

character: If not NULL, any file names matching those specified will be ignored in any "source(filename)" within the scripts.

Value

Returns a list with 2 dataframes (a) nodes with columns id, assign, member, function, code, and (b) edges with columns to and from


dkary/dataflow documentation built on Dec. 20, 2021, 12:06 a.m.