Description Usage Arguments Value
Extract nodes and edges from R code
1 |
path_to_file |
character: A file path string |
ignore_source |
character: If not NULL, any file names matching those specified will be ignored in any "source(filename)" within the scripts. |
Returns a list with 2 dataframes (a) nodes with columns id, assign, member, function, code, and (b) edges with columns to and from
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.